<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>defaultlook</name>
    <message>
        <location filename="defaultlook.ui" line="20"/>
        <location filename="defaultlook.cpp" line="58"/>
        <location filename="defaultlook.cpp" line="502"/>
        <location filename="defaultlook.cpp" line="509"/>
        <location filename="defaultlook.cpp" line="526"/>
        <location filename="defaultlook.cpp" line="537"/>
        <location filename="defaultlook.cpp" line="547"/>
        <source>MX Tweak</source>
        <translation>MX Ajustements</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="54"/>
        <source>Xfce Settings</source>
        <translation>Paramètres de Xfce</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="63"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Personnalisez le tableau de bord&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="77"/>
        <location filename="defaultlook.ui" line="283"/>
        <source>Panel</source>
        <translation>Tableau de bord</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="97"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configurez le comportement des fenêtres et les raccourcis&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="111"/>
        <source>Window Manager</source>
        <translation>Gestionnaire des fenêtres</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="131"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Personnalisez l&apos;apparence de votre bureau&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="145"/>
        <source>Appearance</source>
        <translation>Apparence</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="223"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="234"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="251"/>
        <source>Quit application</source>
        <translation>Quitter l&apos;application</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="254"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="261"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="291"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="311"/>
        <source>Backup current panel configuration</source>
        <translation>Enregistrer la configuration actuelle du tableau de bord</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="318"/>
        <source>Restore backup panel configuration</source>
        <translation>Rétablir la configuration actuelle du tableau de bord</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="325"/>
        <source>Restore default panel</source>
        <translation>Rétablir le tableau de bord par défaut</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="338"/>
        <source>Affects 1st panel</source>
        <translation>Effets sur le 1er tableau de bord</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="345"/>
        <source>Display panel vertically</source>
        <translation>Afficher le tableau de bord verticalement</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="365"/>
        <source>Bottom</source>
        <translation>Bas</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="370"/>
        <source>Top</source>
        <translation>Haut</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="378"/>
        <source>Display panel horizontally</source>
        <translation>Afficher le tableau de bord horizontalement</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="398"/>
        <source>Left</source>
        <translation>Gauche</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="403"/>
        <source>Right</source>
        <translation>Droite</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="411"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Effets sur tous les tableaux de bord&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="431"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Boutons des fenêtres&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="446"/>
        <location filename="defaultlook.ui" line="549"/>
        <location filename="defaultlook.ui" line="740"/>
        <location filename="defaultlook.ui" line="894"/>
        <location filename="defaultlook.ui" line="936"/>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="469"/>
        <source>Theme</source>
        <translation>Thème</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="483"/>
        <source>Theme Options</source>
        <translation>Options du thème</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="513"/>
        <source>Fix some website fields when using dark theme</source>
        <translation>Corrige les champs de remplissage sur certains sites avec un thème sombre</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="516"/>
        <source>Firefox dark theme tweak</source>
        <translation>Ajustement pour le thème sombre de Firefox</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="523"/>
        <source>Fix HexChat input box in dark theme</source>
        <translation>Corriger la fenêtre de saisie de HexChat avec un thème sombre</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="575"/>
        <source>Undo</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="582"/>
        <source>Preview</source>
        <translation>Aperçu</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="589"/>
        <source>Remove User Theme Set</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="defaultlook.ui" line="600"/>
        <source>Save Current Settings as a Theme Set</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="defaultlook.ui" line="614"/>
        <location filename="defaultlook.ui" line="760"/>
        <source>Compositor</source>
        <translation>Compositeur</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="635"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Lancer l&apos;outil de configuration compton-conf</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="638"/>
        <source>Compton settings</source>
        <translation>Paramètres de Compton</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="662"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Paramètres du  compositeur de Xfce&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="665"/>
        <source>Xfwm Settings</source>
        <translation>Paramètres de Xfwm</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="689"/>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="694"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Compositeur Xfwm (Xfce)</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="699"/>
        <source>Compton </source>
        <translation>Compton</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="707"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Éditer directement compton.conf dans un éditeur de texte</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="710"/>
        <source>Edit compton.conf</source>
        <translation>Éditer compton.conf</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="767"/>
        <source>Transparency and shadow options</source>
        <translation>Options de transparence et d&apos;ombrage</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="774"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="defaultlook.ui" line="777"/>
        <source>VBlank</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="defaultlook.ui" line="785"/>
        <source>auto</source>
        <translation>auto</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="790"/>
        <source>glx</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="defaultlook.ui" line="795"/>
        <source>xpresent</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="defaultlook.ui" line="800"/>
        <source>off</source>
        <translation>off</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="811"/>
        <source>Config Options</source>
        <translation>Options de configuration</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="819"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Réinitialiser le thème de Lightdm (écran de connexion)</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="826"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Réinitialiser les actions personnalisées via clic droit de Thunar</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="833"/>
        <source>Use intel driver instead of default &quot;modsetting&quot; driver (requires restart)</source>
        <translation>Utiliser le pilote intel à la place du pilote par défaut &quot;modsetting&quot; (nécessite un redémarrage)</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="840"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>          NOTE:  /etc/X11/xorg.conf.d/20-intel.conf existant sera sauvegardé dans le dossier personnel</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="847"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Utiliser option sans tearing amdgpu</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="854"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>NOTE: l&apos;actuelle configuration /etc/X11/xorg.conf.d/20-amd.conf sera sauvegardée dans le répertoire utilisateur</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="861"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Utiliser option sans tearing du pilote radeon</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="868"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>NOTE: l&apos;actuelle configuration /etc/X11/xorg.conf.d/20-radeon.conf sera sauvegardée dans le répertoire utilsateur</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="908"/>
        <source>Other</source>
        <translation>Autre</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="916"/>
        <source>Enable single-click on desktop</source>
        <translation>Activer le simple clic sur le bureau</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="923"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Activer le simple clic dans le gestionnaire de fichier Thunar</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="960"/>
        <source>Show systray (notification area) frame</source>
        <translation>Afficher le cadre de la systray (zone de notification)</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="967"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Afficher les fenêtres de tous les espaces de travail dans le tableau de bord</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="974"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Activer le montage de disques internes par des utilisateurs non root</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="981"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Désactiver l&apos;abréviation des noms de fichiers longs sur le bureau</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="988"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Activer l&apos;hibernation à partir du menu de déconnexion</translation>
    </message>
    <message>
        <location filename="defaultlook.ui" line="995"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>                   note: pour basculer en hibernation, le fichier d&apos;échange doit être &gt;= RAM</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="501"/>
        <source>About MX Tweak</source>
        <translation>À propos de MX Ajustements</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="502"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="503"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Une application pour changer et ajuster rapidement les thèmes de l&apos;interface par défaut</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="505"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="506"/>
        <location filename="defaultlook.cpp" line="509"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="507"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="538"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Terminé! Firefox peut nécessiter un redémarrage pour activer les changements </translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="548"/>
        <source>This app is Xfce-only</source>
        <translation>Cette application ne fonctionne que pour Xfce</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="690"/>
        <source>Panel settings</source>
        <translation>Paramètres du tableau de bord</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="691"/>
        <source> Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>Les paramètres actuels de votre tableau de bord ont été enregistrés dans un dossier caché nommé .restore dans votre dossier personnel (~/.restore/)</translation>
    </message>
    <message>
        <location filename="defaultlook.cpp" line="1117"/>
        <source>Choose a theme set</source>
        <translation>Choisir un jeu de thèmes</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="window_buttons.ui" line="14"/>
        <location filename="window_buttons.cpp" line="37"/>
        <source>Window Buttons</source>
        <translation>Boutons des fenêtres</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Apparence&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Afficher le nom des boutons</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Afficher les boutons plats</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Afficher la poignée</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Ordre de tri :</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Horodatage</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Titre du groupe et horodatage</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Titre de la fenêtre</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Titre du groupe et de la fenêtre</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Aucun, autoriser le glisser-déposer</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Comportement&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Groupement de fenêtres :</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Jamais</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Toujours</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Action du clic du milieu :</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Aucune</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Fermer la fenêtre</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Minimiser la fenêtre</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Restaurer les fenêtres réduites dans l’espace de travail actif</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Afficher le cadre de la fenêtre au survol d’un bouton</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Changer de fenêtre à l’aide de la molette de la souris</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtrage&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Afficher les fenêtres de tous les espaces de travail ou fenêtres</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Afficher uniquement les fenêtres réduites</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Afficher les fenêtres de tous les moniteurs</translation>
    </message>
    <message>
        <location filename="window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Boîte de dialogue</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Fenêtres contextuelles (popup)</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Fenêtres lors du déplacement</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Paramètres d&apos;opacité&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Décors des fenêtres</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Afficher des ombres sous les fenêtres ancrées</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Afficher des ombres sous les fenêtres contextuelles (popup)</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Fenêtres lors du redimensionnement</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Afficher des ombres sous les fenêtres régulières</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Paramètres de fonction&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Afficher un aperçu des fenêtres plutôt que des icônes lors de l&apos;alternance</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Afficher directement le recouvrement de fenêtres en plein écran</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Fenêtres inactives</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Synchroniser le rendu avec le rafraîchissement vertical</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="xfwm_compositor_settings.cpp" line="39"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Paramètres du compositeur Xfmw</translation>
    </message>
</context>
</TS>